==> marble_4.13.0.orig.tar.xz: marble-4.13.0/src/lib/marble/geodata/parser/GeoDataTypes.cpp <==
/*
    Copyright (C) 2008 Jens-Michael Hoffmann <jensmh@gmx.de>

    This file is part of the KDE project

    This library is free software you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    aint with this library see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#include "GeoDataTypes.h"

namespace Marble
{

namespace GeoDataTypes
{
const char* GeoDataAnimatedUpdateType = "GeoDataAnimatedUpdate";
const char* GeoDataAliasType = "GeoDataAlias";
const char* GeoDataCameraType = "GeoDataCamera";
const char* GeoDataColorStyleType = "GeoDataColorStyle";
const char* GeoDataContainerType = "GeoDataContainer";
const char* GeoDataDataType = "GeoDataData";
const char* GeoDataDocumentType = "GeoDataDocument";
const char* GeoDataExtendedDataType = "GeoDataExtendedData";
const char* GeoDataFeatureType = "GeoDataFeature";
const char* GeoDataFlyToType = "GeoDataFlyTo";
const char* GeoDataFolderType = "GeoDataFolder";
const char* GeoDataGeometryType = "GeoDataGeometry";
const char* GeoDataGroundOverlayType = "GeoDataGroundOverlay";
const char* GeoDataHotspotType = "GeoDataHotspot";
const char* GeoDataIconStyleType = "GeoDataIconStyle";
const char* GeoDataInnerBoundaryType = "GeoDataInnerBoundary";
const char* GeoDataLabelStyleType = "GeoDataLabelStyle";
const char* GeoDataLatLonAltBoxType = "GeoDataLatLonAlt";
const char* GeoDataLatLonBoxType = "GeoDataLatLonBox";
const char* GeoDataLatLonQuadType = "GeoDataLatLonQuad";
const char* GeoDataLinearRingType = "GeoDataLinearRing";
const char* GeoDataLineStringType = "GeoDataLineString";
const char* GeoDataLineStyleType = "GeoDataLineStyle";
const char* GeoDataLinkType = "GeoDataLink";
const char* GeoDataLocationType = "GeoDataLocation";
const char* GeoDataLodType = "GeoDataLod";
const char* GeoDataLookAtType = "GeoDataLookAt";
const char* GeoDataModelType = "GeoDataModel";
const char* GeoDataMultiGeometryType = "GeoDataMultiGeometry";
const char* GeoDataMultiTrackType = "GeoDataMultiTrack";
const char* GeoDataNetworkLinkType = "GeoDataNetworkLink";
const char* GeoDataOrientationType = "GeoDataOrientation";
const char* GeoDataOuterBoundaryType = "GeoDataOuterBoundary";
const char* GeoDataPhotoOverlayType = "GeoDataPhotoOverlay";
const char* GeoDataPlacemarkType = "GeoDataPlacemark";
const char* GeoDataPlaylistType = "GeoDataPlaylist";
const char* GeoDataPointType = "GeoDataPoint";
const char* GeoDataPolygonType = "GeoDataPolygon";
const char* GeoDataPolyStyleType = "GeoDataPolyStyle";
const char* GeoDataRegionType = "GeoDataRegion";
const char* GeoDataResourceMapType = "GeoDataResourceMap";
const char* GeoDataSimpleArrayDataType = "GeoDataSimpleArrayData";
const char* GeoDataStyleSelectorType = "GeoDataStyleSelector";
const char* GeoDataStyleType = "GeoDataStyle";
const char* GeoDataStyleMapType = "GeoDataStyleMap";
const char* GeoDataSoundCueType = "GeoDataSoundCue";
const char* GeoDataTimePrimitiveType = "GeoDataTimePrimitive";
const char* GeoDataTimeSpanType = "GeoDataTimeSpan";
const char* GeoDataTimeStampType = "GeoDataTimeStamp";
const char* GeoDataTourType = "GeoDataTour";
const char* GeoDataTourControlType = "GeoDataTourControl";
const char* GeoDataWaitType = "GeoDataWait";
const char* GeoDataTrackType = "GeoDataTrack";
const char* GeoDataScaleType = "GeoDataScale";
const char* GeoDataScreenOverlayType = "GeoDataScreenOverlay";
const char* GeoDataBalloonStyleType = "GeoDataBalloonStyle";
const char* GeoDataListStyleType = "GeoDataListStyle";
const char* GeoDataItemIconType = "GeoDataItemIcon";
const char* GeoDataImagePyramidType = "GeoDataImagePyramid";
const char* GeoDataViewVolumeType = "GeoDataViewVolume";
const char* GeoDataNetworkLinkControlType = "GeoDataNetworkLinkControl";
const char* GeoDataUpdateType = "GeoDataUpdate";
}

}

==> marble-4.14.3.tar.xz: marble-4.14.3/src/lib/marble/geodata/parser/GeoDataTypes.cpp <==
/*
    Copyright (C) 2008 Jens-Michael Hoffmann <jensmh@gmx.de>

    This file is part of the KDE project

    This library is free software you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    aint with this library see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#include "GeoDataTypes.h"

namespace Marble
{

namespace GeoDataTypes
{
const char* GeoDataAnimatedUpdateType = "GeoDataAnimatedUpdate";
const char* GeoDataAliasType = "GeoDataAlias";
const char* GeoDataCameraType = "GeoDataCamera";
const char* GeoDataChangeType = "GeoDataChange";
const char* GeoDataColorStyleType = "GeoDataColorStyle";
const char* GeoDataContainerType = "GeoDataContainer";
const char* GeoDataCreateType = "GeoDataCreate";
const char* GeoDataDataType = "GeoDataData";
const char* GeoDataDeleteType = "GeoDataDelete";
const char* GeoDataDocumentType = "GeoDataDocument";
const char* GeoDataExtendedDataType = "GeoDataExtendedData";
const char* GeoDataFeatureType = "GeoDataFeature";
const char* GeoDataFlyToType = "GeoDataFlyTo";
const char* GeoDataFolderType = "GeoDataFolder";
const char* GeoDataGeometryType = "GeoDataGeometry";
const char* GeoDataGroundOverlayType = "GeoDataGroundOverlay";
const char* GeoDataHotspotType = "GeoDataHotspot";
const char* GeoDataIconStyleType = "GeoDataIconStyle";
const char* GeoDataInnerBoundaryType = "GeoDataInnerBoundary";
const char* GeoDataLabelStyleType = "GeoDataLabelStyle";
const char* GeoDataLatLonAltBoxType = "GeoDataLatLonAlt";
const char* GeoDataLatLonBoxType = "GeoDataLatLonBox";
const char* GeoDataLatLonQuadType = "GeoDataLatLonQuad";
const char* GeoDataLinearRingType = "GeoDataLinearRing";
const char* GeoDataLineStringType = "GeoDataLineString";
const char* GeoDataLineStyleType = "GeoDataLineStyle";
const char* GeoDataLinkType = "GeoDataLink";
const char* GeoDataLocationType = "GeoDataLocation";
const char* GeoDataLodType = "GeoDataLod";
const char* GeoDataLookAtType = "GeoDataLookAt";
const char* GeoDataModelType = "GeoDataModel";
const char* GeoDataMultiGeometryType = "GeoDataMultiGeometry";
const char* GeoDataMultiTrackType = "GeoDataMultiTrack";
const char* GeoDataNetworkLinkType = "GeoDataNetworkLink";
const char* GeoDataOrientationType = "GeoDataOrientation";
const char* GeoDataOuterBoundaryType = "GeoDataOuterBoundary";
const char* GeoDataPhotoOverlayType = "GeoDataPhotoOverlay";
const char* GeoDataPlacemarkType = "GeoDataPlacemark";
const char* GeoDataPlaylistType = "GeoDataPlaylist";
const char* GeoDataPointType = "GeoDataPoint";
const char* GeoDataPolygonType = "GeoDataPolygon";
const char* GeoDataPolyStyleType = "GeoDataPolyStyle";
const char* GeoDataRegionType = "GeoDataRegion";
const char* GeoDataResourceMapType = "GeoDataResourceMap";
const char* GeoDataSchemaType = "GeoDataSchema";
const char* GeoDataSimpleFieldType = "GeoDataSimpleField";
const char* GeoDataSimpleArrayDataType = "GeoDataSimpleArrayData";
const char* GeoDataStyleSelectorType = "GeoDataStyleSelector";
const char* GeoDataStyleType = "GeoDataStyle";
const char* GeoDataStyleMapType = "GeoDataStyleMap";
const char* GeoDataSoundCueType = "GeoDataSoundCue";
const char* GeoDataTimePrimitiveType = "GeoDataTimePrimitive";
const char* GeoDataTimeSpanType = "GeoDataTimeSpan";
const char* GeoDataTimeStampType = "GeoDataTimeStamp";
const char* GeoDataTourType = "GeoDataTour";
const char* GeoDataTourControlType = "GeoDataTourControl";
const char* GeoDataWaitType = "GeoDataWait";
const char* GeoDataTrackType = "GeoDataTrack";
const char* GeoDataScaleType = "GeoDataScale";
const char* GeoDataScreenOverlayType = "GeoDataScreenOverlay";
const char* GeoDataBalloonStyleType = "GeoDataBalloonStyle";
const char* GeoDataListStyleType = "GeoDataListStyle";
const char* GeoDataItemIconType = "GeoDataItemIcon";
const char* GeoDataImagePyramidType = "GeoDataImagePyramid";
const char* GeoDataViewVolumeType = "GeoDataViewVolume";
const char* GeoDataNetworkLinkControlType = "GeoDataNetworkLinkControl";
const char* GeoDataUpdateType = "GeoDataUpdate";
}

}
